@@ -41,6 +41,9 @@
 #include <QMouseEvent>
 #include <QLayout>
 
+namespace Filelight
+{
+
 struct Disk
 {
     QString mount;
@@ -60,6 +63,8 @@ struct DiskList : QList<Disk>
 
 class MyRadialMap : public RadialMap::Widget
 {
+    Q_OBJECT
+
 public:
     MyRadialMap(QWidget *parent)
             : RadialMap::Widget(parent, true)
@@ -148,7 +153,7 @@ void SummaryWidget::createDiskMaps()
 
         map->create(tree); //must be done when visible
 
-        connect(map, SIGNAL(activated(QUrl)), SIGNAL(activated(QUrl)));
+        connect(map, &RadialMap::Widget::activated, this, &SummaryWidget::activated);
     }
 }
 
@@ -182,3 +187,7 @@ DiskList::DiskList()
         *this += disk;
     }
 }
+
+}
+
+#include "summaryWidget.moc"
